@@ -66,6 +66,9 @@ class DynamicDynamoDBDaemon(Daemon):
             for table_name, key_name in sorted(table_names):
                 core.ensure_provisioning(table_name, key_name)
 
+            # Sleep between the checks
+            time.sleep(check_interval)
+
 
 def main():
     """ Main function called from dynamic-dynamodb """
